Workflow Team Web Tools
=======================

|build|

workflowwebtools  - Provides a server for Production and Reprocessing operations

Installation
~~~~~~~~~~~~

:: 

    pip install workflowwebtools

.. |build| image:: https://travis-ci.org/CMSCompOps/WorkflowWebTools.svg?branch=master
    :target: https://travis-ci.org/CMSCompOps/WorkflowWebTools
